'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var react = require('react');
var constants = require('../constants.js');
var PolarisVizContext = require('../contexts/PolarisVizContext.js');
var useChartContext = require('./useChartContext.js');

function useTheme(passedTheme) {
  var _ref, _ref2;
  const {
    themes,
    defaultTheme
  } = react.useContext(PolarisVizContext.PolarisVizContext);
  const {
    theme
  } = useChartContext.useChartContext();
  const themeName = (_ref = (_ref2 = passedTheme !== null && passedTheme !== void 0 ? passedTheme : theme) !== null && _ref2 !== void 0 ? _ref2 : defaultTheme) !== null && _ref !== void 0 ? _ref : constants.DEFAULT_THEME_NAME;
  const hasValidTheme = Object.prototype.hasOwnProperty.call(themes, themeName);
  react.useEffect(() => {
    if (!hasValidTheme) {
      // eslint-disable-next-line no-console
      console.warn(`${themeName} theme not found, falling back to ${constants.DEFAULT_THEME_NAME}. Did you forget to define it in the PolarisVizProvider?`);
    }
  }, [hasValidTheme, themeName]);
  if (hasValidTheme) {
    return themes[themeName];
  } else {
    return themes[constants.DEFAULT_THEME_NAME];
  }
}

exports.useTheme = useTheme;
