'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var constants = require('../constants.js');

const BASE_THEMES = {
  Dark: constants.DARK_THEME,
  Light: constants.LIGHT_THEME,
  Print: constants.PRINT_THEME
};
const createTheme = (theme, baseTheme = BASE_THEMES[constants.DEFAULT_THEME_NAME]) => {
  const themeKeys = Object.keys(baseTheme);
  return themeKeys.reduce((accumulator, key) => {
    const defaultValue = baseTheme[key];
    const value = theme[key];
    if (typeof defaultValue === 'string' || typeof value === 'string' || Array.isArray(defaultValue)) {
      accumulator[key] = value == null ? defaultValue : value;
    } else {
      accumulator[key] = {
        ...baseTheme[key],
        ...theme[key]
      };
    }
    return accumulator;
  }, {});
};
const createThemes = themeRecord => {
  return Object.keys(themeRecord).reduce((accumulator, themeName) => {
    accumulator[themeName] = createTheme(themeRecord[themeName], BASE_THEMES[themeName]);
    return accumulator;
  }, {});
};

exports.createTheme = createTheme;
exports.createThemes = createThemes;
