import { ChartMargin, Y_AXIS_CHART_SPACING, LABEL_AREA_MIN_SPACING, LABEL_AREA_TOP_SPACING } from '../constants.js';
import { useTheme } from './useTheme.js';

function useChartPositions({
  annotationsHeight,
  height,
  width,
  xAxisHeight,
  yAxisWidth
}) {
  const {
    grid: {
      horizontalMargin
    }
  } = useTheme();
  const chartXPosition = horizontalMargin + yAxisWidth + Y_AXIS_CHART_SPACING;
  const chartYPosition = ChartMargin.Top + annotationsHeight;
  const xAxisLabelSpacing = xAxisHeight === 0 ? LABEL_AREA_MIN_SPACING : LABEL_AREA_TOP_SPACING;
  const drawableHeight = height - chartYPosition - xAxisHeight - xAxisLabelSpacing;
  const drawableWidth = width - chartXPosition - horizontalMargin;
  return {
    chartXPosition,
    chartYPosition,
    drawableHeight,
    drawableWidth,
    xAxisBounds: {
      x: chartXPosition,
      y: drawableHeight + xAxisLabelSpacing + chartYPosition
    },
    yAxisBounds: {
      x: horizontalMargin,
      y: chartYPosition
    }
  };
}

export { useChartPositions };
