import { DEFAULT_THEME_NAME, DARK_THEME, LIGHT_THEME, PRINT_THEME } from '../constants.js';

const BASE_THEMES = {
  Dark: DARK_THEME,
  Light: LIGHT_THEME,
  Print: PRINT_THEME
};
const createTheme = (theme, baseTheme = BASE_THEMES[DEFAULT_THEME_NAME]) => {
  const themeKeys = Object.keys(baseTheme);
  return themeKeys.reduce((accumulator, key) => {
    const defaultValue = baseTheme[key];
    const value = theme[key];
    if (typeof defaultValue === 'string' || typeof value === 'string' || Array.isArray(defaultValue)) {
      accumulator[key] = value == null ? defaultValue : value;
    } else {
      accumulator[key] = {
        ...baseTheme[key],
        ...theme[key]
      };
    }
    return accumulator;
  }, {});
};
const createThemes = themeRecord => {
  return Object.keys(themeRecord).reduce((accumulator, themeName) => {
    accumulator[themeName] = createTheme(themeRecord[themeName], BASE_THEMES[themeName]);
    return accumulator;
  }, {});
};

export { createTheme, createThemes };
